*******************
Authors and Credits
*******************

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.1214268.svg
   :target: https://doi.org/10.5281/zenodo.1214268
   :alt: DOI 10.5281/zenodo.1214268

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy

If you used this package in your research, please cite it via DOI
`10.5281/zenodo.1214268 <https://doi.org/10.5281/zenodo.1214268>`_.

Authors
=======

* Marten van Kerkwijk (@mhvk)
* Chenchong Charles Zhu (@cczhu)

Other contributors (alphabetical)
=================================

* Shaoguang Guo (@shaoguangleo)
* Rebecca Lin (@00rebe)
* Nikhil Mahajan (@theXYZT)
* Robert Main (@ramain)
* David McKenna (@David-McKenna)
* Dana Simard (@danasimard)
* George Stein (@georgestein)
* Rik van Lieshout (@rikvl)

If you have contributed to Baseband but are not listed above, please send one
of the authors an e-mail, or `open a pull request for this page
<https://github.com/mhvk/baseband/edit/master/AUTHORS.rst>`_.
